/**
 * Metrics service is a set of utility classes to enable a Java
 * programmer to send metrics to the Zabbix monitoring tool.
 * 
 * Copyright 2007, Gerco Dries (gdr@progaia-rs.nl).
 * 
 * Metrics service is free software: you can redistribute it 
 * and/or modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 2 of 
 * the License, or (at your option) any later version.
 *
 * Metrics service is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Metrics service.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.progaia.metricsservice;

import java.io.PrintWriter;

import com.sonicsw.xq.XQLog;

/**
 * PrefixingLogger adds a prefix to log messages to prevent the service developer
 * from having to type the prefix every time.
 * 
 * @author Gerco Dries (gdr@progaia-rs.nl)
 *
 */
public class PrefixingLogger implements XQLog {

	private final String logPrefix;
	private final XQLog xqLog;
	
	public PrefixingLogger(String prefix, XQLog logger) {
		logPrefix = prefix;
		xqLog = logger; 
	}

	public void logInformation(String arg0) {
		xqLog.logInformation(logPrefix + arg0);
	}

	public void logInformation(Throwable arg0) {
		xqLog.logInformation(arg0);
	}

	public void logWarning(String arg0) {
		xqLog.logWarning(logPrefix + arg0);
	}

	public void logWarning(Throwable arg0) {
		xqLog.logWarning(arg0);
	}

	public void logError(String arg0) {
		xqLog.logError(logPrefix + arg0);
	}

	public void logError(Throwable arg0) {
		xqLog.logError(arg0);
	}

	public PrintWriter getPrintWriter() {
		return xqLog.getPrintWriter();
	}

	public void logDebug(String arg0) {
		xqLog.logDebug(logPrefix + arg0);
	}

	public void logDebug(Throwable arg0) {
		xqLog.logDebug(arg0);
	}

	public boolean isDebugLoggingEnabled() {
		return xqLog.isDebugLoggingEnabled();
	}

}
